virtualaddresseditor — Camelot documentation

### Navigation

- index
- modules |
- next |
- previous |
- Camelot documentation »
- Camelot API »
- view »
- controls »
- editors »

# virtualaddresseditor

`camelot.view.controls.editors.virtualaddresseditor.` `default_address_validator`(address_type, address)

  Validates wether a virtual address is valid and correct it if possible. :param address_type: the type of address to validate, eg ‘phone’ :param address: the address itself :return: (valid, corrected_address) a tuple with a :type:`boolean`

  > indicating if the address is valid and a string with the corrected address.

### Navigation

- index
- modules |
- next |
- previous |
- Camelot documentation »
- Camelot API »
- view »
- controls »
- editors »

Comments
blog comments powered by Disqus